##############################################################################
#
# Copyright (c) 2003 - Tue Wennerberg - All Rights Reserved
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

from Globals import Persistent, MessageDialog, HTML, package_home
import os
import OFS.SimpleItem, Acquisition, OFS.ObjectManager, OFS.PropertyManager
import AccessControl.Role, sys, os, stat, traceback
from App.Management import Navigation
from ComputedAttribute import ComputedAttribute
from AccessControl import ClassSecurityInfo

from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from Products.PageTemplates import ZopePageTemplate
from Products.ExternalMethod import ExternalMethod
from OFS import Folder

################################################################################

ZPT_DIR=os.path.join(package_home(globals()), 'zpt')

manage_addAccountForm=PageTemplateFile(os.path.join(ZPT_DIR,'addAccountForm.zpt'))


def manage_addAccount(self, id, title='', REQUEST=None):
    """Add a Account instance
    """
    id = str(id)
    title = str(title)

    # Create new object instance
    newobj = Account(id, title)
    
    # Add to current container
    self._setObject(id, newobj)

    if REQUEST is not None:
        return self.manage_main(self,REQUEST)

################################################################################

class Account( OFS.ObjectManager.ObjectManager,
               OFS.PropertyManager.PropertyManager,
               OFS.SimpleItem.Item,
               Persistent,
               Acquisition.Implicit,
               AccessControl.Role.RoleManager,
               Navigation ):

    meta_type = 'TimeReg Account'
    
    """
    Account
    """

    def __init__(self, id, title):

        self.id = id
        self.rounding_method = 'round'
        self.rounding_precision = 5
        self.manage_edit(title)

    ZopeTime = Acquisition.Acquired
    HelpSys  = Acquisition.Acquired
    security = ClassSecurityInfo()

    rounding_methods = ['up', 'round', 'down']

    _properties = (
        {'id':'title', 'type':'string', 'mode':'w'},
        {'id':'rounding_method', 'type':'selection', 'mode':'w',
         'select_variable': 'rounding_methods'},
        {'id':'rounding_precision', 'type':'int', 'mode':'w'},
        )
    
    manage_options = (
        OFS.ObjectManager.ObjectManager.manage_options +
        OFS.PropertyManager.PropertyManager.manage_options +
        OFS.SimpleItem.Item.manage_options +
        AccessControl.Role.RoleManager.manage_options
    )

    __ac_permissions__ = (
        ('View', ('__call__','')),
    )

    def manage_edit(self,
                    title='',
                    REQUEST=None):
        """Change the event
        """
        self.title     = str(title)


        if REQUEST:
            message="Object updated."
            return self.manage_main(self,REQUEST,manage_tabs_message=message)

    def projects(self):
        """ Accounts
        """
        return self.objectValues('TimeReg Project')
